@@ -144,9 +144,9 @@ class Client(object):
         bmgr = BucketManager(self.auth,self.cfg.mgr_url)
         return bmgr.bucket_list()
 
-    def bucket_stat(self, name, startdate, enddate):
+    def bucket_stat(self, name, startdate, enddate,isListDetails='false',storageType=None):
         bmgr = BucketManager(self.auth,self.cfg.mgr_url)
-        return bmgr.bucket_stat(name, startdate, enddate)
+        return bmgr.bucket_stat(name, startdate, enddate,isListDetails='false',storageType=storageType)
 
     def bucket_statistics(self, name, stype, startdate, enddate, isListDetails='false'):
         bmgr = BucketManager(self.auth,self.cfg.mgr_url)
